@@ -262,7 +262,7 @@ class RKXMLRequest(XMLRequest):
                                              order_name=order.get('OrderName'),
                                              url=(order.get('Url')),
                                              version=order.get('Version'),
-                                             crc32=order.get('Crc32'),
+                                             crc32=order.get('crc32'),
                                              guid=order.get('guid'),
                                              table_id=(order.get('TableID')),
                                              table_code=order.get('TableCode'),
